@@ -10,16 +10,16 @@ pruneNodes<-function(bn){
   Q <- bn$Q  
   U <- union(paste0(rep(names(E),each=2),c("_p","_m"),sep=""),Q)
   dout    <- degree(bn$DAG,mode="out")
-  leavesfb<-names(dout)[dout==0]
-  out<-leavesfb[!leavesfb%in%U]
+  leaves<-names(dout)[dout==0]
+  out<-leaves[!leaves%in%U]
   while(length(out)>0){
    bn$DAG<-delete_vertices(bn$DAG,out)
    bn$CPTs[out] <- NULL
    
    dout    <- degree(bn$DAG,mode="out")
-   leavesfb<-names(dout)[dout==0]
+   leaves<-names(dout)[dout==0]
    
-   out<-leavesfb[!leavesfb%in%U]
+   out<-leaves[!leaves%in%U]
   }
   return(bn)
 }
